@@ -1,4 +1,3 @@
-import six
 
 
 class DependencyCollection(object):
@@ -15,5 +14,5 @@ class DependencyCollection(object):
             else self._provider.resolve(members)
 
     def __iter__(self):
-        for i, name in enumerate(self._names):
+        for _, name in enumerate(self._names):
             yield self._provider.resolve(name)
