@@ -4,6 +4,8 @@ import pkg_resources
 
 IOC_ENTRYPOINT_NAME = 'ioc.providers'
 
+IS_CONFIGURED = False
+
 
 def get_providers():
     """Return the mapping of inversion-of-control providers and their
@@ -20,7 +22,13 @@ def setup():
     """Load all :term:`Dependency Providers` and start setting up the
     dependencies container.
     """
+    global IS_CONFIGURED
+    if IS_CONFIGURED:
+        return
+
     for name, module in get_providers():
         if not hasattr(module, 'setup_ioc'):
             continue
         module.setup_ioc()
+
+    IS_CONFIGURED = True
